==> apache-shenyu-2.5.1-src.zip: apache-shenyu-2.5.1-src/shenyu-plugin/shenyu-plugin-logging/shenyu-plugin-logging-common/src/main/java/org/apache/shenyu/plugin/logging/common/collector/LogCollector.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.plugin.logging.common.collector;

import org.apache.shenyu.plugin.logging.common.entity.ShenyuRequestLog;
import org.apache.shenyu.plugin.logging.mask.api.matcher.KeyWordMatch;

/**
 * Collect logs and put into buffer queue.
 */
public interface LogCollector<L extends ShenyuRequestLog> extends AutoCloseable {

    /**
     * start log collector.
     */
    void start();

    /**
     * mask log.
     *
     * @param log log
     * @param keyWordMatch keyWordMatch
     * @param dataMaskALg data mask algorithm
     */
    void mask(L log, KeyWordMatch keyWordMatch, String dataMaskALg);

    /**
     * collect log.
     *
     * @param log access log
     */
    void collect(L log);
}

==> apache-shenyu-2.7.0.1-src.zip: apache-shenyu-2.7.0.1-src/shenyu-plugin/shenyu-plugin-logging/shenyu-plugin-logging-common/src/main/java/org/apache/shenyu/plugin/logging/common/collector/LogCollector.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.plugin.logging.common.collector;

import org.apache.shenyu.plugin.logging.common.entity.ShenyuRequestLog;
import org.apache.shenyu.plugin.logging.desensitize.api.matcher.KeyWordMatch;

/**
 * Collect logs and put into buffer queue.
 */
public interface LogCollector<L extends ShenyuRequestLog> extends AutoCloseable {

    /**
     * start log collector.
     */
    void start();

    /**
     * desensitize log.
     *
     * @param log log
     * @param keyWordMatch keyWordMatch
     * @param desensitizeAlg data desensitize algorithm
     */
    void desensitize(L log, KeyWordMatch keyWordMatch, String desensitizeAlg);

    /**
     * collect log.
     *
     * @param log access log
     */
    void collect(L log);
}
